@@ -371,7 +371,7 @@ def LipIntValues( n, Dim, Ndata, x, Xd, y, Lipconst, Index, id = 0):
     pLipconstnp, pLipconst = convert_py_float_to_cffi( Lipconst)
     pIndexnp, pIndex = convert_py_int_to_cffi( Index)
 
-    pred = [ fm.LipIntValue( id, pDim, pNdata, px[i,:], pXd, py, pLipconst, pIndex) for i in range( 0, n)]
+    pred = [ fm.LipIntValue( id, pDim, pNdata, px[i * Dim], pXd, py, pLipconst, pIndex) for i in range( 0, n)]
     return pred
 
 
